==> nsaname-1.0.11.tgz: package/lib/nsaname.js <==
// Names derived from https://en.wikipedia.org/wiki/NSA_ANT_catalog

const first = [
  'After',
  'Angel',
  'Ant',
  'Athena',
  'Aurora',
  'Badass',
  'Bald',
  'Bar',
  'Basic',
  'Bee',
  'Bizantine',
  'Black',
  'Blarney',
  'Bothan',
  'Brutal',
  'Bull',
  'Candy',
  'Cherry',
  'Chimay',
  'Cocoon',
  'Code',
  'Connectify',
  'Cotton',
  'Couch',
  'Crisscross',
  'Cross',
  'Cut',
  'Dance',
  'Dapino',
  'Defiant',
  'Deity',
  'Der',
  'Doctor',
  'Dr',
  'Drifting',
  'Dropout',
  'Earl',
  'Express',
  'Fair',
  'Fashion',
  'Feed',
  'Felix',
  'Fight',
  'Fine',
  'Fire',
  'Flash',
  'Flux',
  'Fly',
  'Frog',
  'Funny',
  'Galant',
  'Gopher',
  'Gourmet',
  'Grass',
  'Green',
  'Gyr',
  'Hair',
  'Halux',
  'Hammer',
  'Harpy',
  'Hat',
  'Head',
  'Hera',
  'Herc',
  'Hidden',
  'High',
  'Hop',
  'Howler',
  'Hyenas',
  'Imperial',
  'Irate',
  'Iron',
  'Jet',
  'Juke',
  'Junior',
  'Karma',
  'Kraken',
  'Long',
  'Loud',
  'Lovely',
  'Maddening',
  'Maestro',
  'Magic',
  'Magical',
  'Marble',
  'Melomy',
  'Midnight',
  'Monkey',
  'Munge',
  'Mutant',
  'Night',
  'Nope',
  'Opulent',
  'Outlaw',
  'Panda',
  'Patient',
  'Philoso',
  'Photo',
  'Poison',
  'Quantum',
  'Quark',
  'Rage',
  'Rain',
  'Raptor',
  'Ricky',
  'Rim',
  'Rock',
  'Roid',
  'Scarlet',
  'School',
  'Secret',
  'Shadows',
  'Sierra',
  'Skid',
  'Sky',
  'Snow',
  'Snowy',
  'Social',
  'Somber',
  'Souffle',
  'Sparrow',
  'Spinal',
  'Spock',
  'Straw',
  'Stucco',
  'Surly',
  'Swap',
  'Tawdry',
  'Tax',
  'The',
  'Time',
  'Titan',
  'Tote',
  'Tremor',
  'Trinity',
  'Turkey',
  'Valiant',
  'Water',
  'Weeping',
  'Wild',
  'Wistful',
  'XKey',
  'Yarn'
]

const second = [
  'Angel',
  'Anglo',
  'Anthropoid',
  'Aquaman',
  'Archimedes',
  'Assassin',
  'Auto',
  'Ball',
  'Bang',
  'Bank',
  'Beam',
  'Beetle',
  'Birds',
  'Bit',
  'Blossom',
  'Bobby',
  'Boom',
  'Bounce',
  'Box',
  'Broth',
  'Bumble',
  'Calendar',
  'Candy',
  'Cannoli',
  'Cascade',
  'Caterpillar',
  'Chef',
  'Cinnamon',
  'Cleft',
  'Club',
  'Country',
  'Cyclone',
  'Cytolysis',
  'Dining',
  'Drill',
  'DriveIn',
  'Dumbo',
  'Eagle',
  'Elsa',
  'Entourage',
  'Fever',
  'Fire',
  'Flight',
  'Floor',
  'Framework',
  'Galleon',
  'Gamma',
  'Genesis',
  'Ghostly',
  'Gibson',
  'Ginsu',
  'Globe',
  'Gold',
  'Gram',
  'Grasshopper',
  'Grey',
  'Hades',
  'Haul',
  'Hawk',
  'Hill',
  'Hole',
  'Hopper',
  'Hornet',
  'Horse',
  'Hurdle',
  'Improvise',
  'Intolerant',
  'Jeep',
  'Kangaroo',
  'Knave',
  'Kraken',
  'Lane',
  'Leviatan',
  'Lithium',
  'Logic',
  'Maestro',
  'Maker',
  'Man',
  'Margarita',
  'Master',
  'Matter',
  'Me',
  'Midnight',
  'Mint',
  'Monk',
  'Monkey',
  'Montana',
  'Mountain',
  'Mouth',
  'Mutt',
  'Nebula',
  'Net',
  'Nut',
  'Owl',
  'Packet',
  'Packrat',
  'Pandemic',
  'Payload',
  'Perseus',
  'Philosoraptor',
  'Picasso',
  'Piece',
  'Plow',
  'Pointe',
  'Poke',
  'Police',
  'Potato',
  'Powerman',
  'Prince',
  'Prism',
  'Proton',
  'Pterodactyl',
  'Pup',
  'Red',
  'Ridge',
  'Rise',
  'Rock',
  'Rowe',
  'Run',
  'Salamander',
  'Score',
  'Scotch',
  'Scribbles',
  'Set',
  'Shooter',
  'Shot',
  'Slasher',
  'Sneeze',
  'Sontaran',
  'Sparrow',
  'Spawn',
  'Spy',
  'Stand',
  'Starke',
  'Sting',
  'Stomper',
  'Surf',
  'Swap',
  'Tap',
  'Tempora',
  'Tender',
  'Theory',
  'Thorugh',
  'Throat',
  'Toll',
  'Transgression',
  'Trap',
  'Trinity',
  'Typhon',
  'View',
  'Vikings',
  'Walk',
  'Warrior',
  'Watch',
  'Water',
  'Wave',
  'Whispers',
  'Wire',
  'Witch',
  'Yard',
  'Zero'
]

const suffixes = [
  'HX', 'I', 'II', 'III', '2000', '4000', '9000', 'Hx9', '2.0', '3.0'
]

/**
 * Returns a nice name for a secret project or tool.
 *
 * @return {string}
 */
function getNSAName (suffix, separator) {
  let nsaname = first[Math.floor(Math.random() * first.length)] +
      separator + second[Math.floor(Math.random() * second.length)]

  if (suffix) {
    nsaname += ' ' +
            suffixes[Math.floor(Math.random() * suffixes.length)]
  }
  return nsaname
}

module.exports = {
  getNSAName: getNSAName,
  wordLists: {
    first: first,
    second: second,
    suffixes: suffixes
  }
}

==> nsaname-1.0.12.tgz: package/lib/nsaname.js <==
/* -*- js-indent-level: 2 -*- */

// Names derived from https://en.wikipedia.org/wiki/NSA_ANT_catalog

const first = [
  'Adapter',
  'After',
  'Angel',
  'Ant',
  'Athena',
  'Aurora',
  'Badass',
  'Bald',
  'Bar',
  'Basic',
  'Bee',
  'Bizantine',
  'Black',
  'Blarney',
  'Blinker',
  'Bothan',
  'Brutal',
  'Bull',
  'Cactus',
  'Candy',
  'Cherry',
  'Chimay',
  'Chuk',
  'Cocoon',
  'Code',
  'Conga',
  'Connectify',
  'Cotton',
  'Couch',
  'Crisscross',
  'Cross',
  'Cut',
  'Dance',
  'Dapino',
  'Defiant',
  'Deity',
  'Der',
  'Doctor',
  'Dr',
  'Dreamy',
  'Drifting',
  'Drizzle',
  'Dropout',
  'Earl',
  'Express',
  'Fair',
  'Fashion',
  'Feed',
  'Felix',
  'Fight',
  'Fine',
  'Fire',
  'Flamenco',
  'Flash',
  'Flux',
  'Fly',
  'Frog',
  'Funny',
  'Galant',
  'Gopher',
  'Gourmet',
  'Grass',
  'Green',
  'Gyr',
  'Hair',
  'Halux',
  'Hammer',
  'Harpy',
  'Hat',
  'Head',
  'Hera',
  'Herc',
  'Hidden',
  'High',
  'Hop',
  'Howler',
  'Hyenas',
  'Imperial',
  'Irate',
  'Iron',
  'Jet',
  'Juke',
  'Junior',
  'Karma',
  'Key',
  'Kraken',
  'Leviticus',
  'Long',
  'Loud',
  'Lovely',
  'Maddening',
  'Maestro',
  'Magic',
  'Magical',
  'Marble',
  'Melomy',
  'Midnight',
  'Monkey',
  'Munge',
  'Mutant',
  'Night',
  'Nope',
  'Nosey',
  'Opulent',
  'Outlaw',
  'Panda',
  'Paranoid',
  'Patient',
  'Philoso',
  'Photo',
  'Poison',
  'Porcupine',
  'Quantum',
  'Quark',
  'Rage',
  'Rain',
  'Rampart',
  'Raptor',
  'Ricky',
  'Rim',
  'Rock',
  'Roid',
  'Salsa',
  'Savior',
  'Scarlet',
  'School',
  'Secret',
  'Shadows',
  'Sierra',
  'Skid',
  'Sky',
  'Slot',
  'Snow',
  'Snowy',
  'Social',
  'Somber',
  'Souffle',
  'Sparrow',
  'Spinal',
  'Spock',
  'Straw',
  'Stucco',
  'Surly',
  'Swap',
  'Tango',
  'Tawdry',
  'Tax',
  'The',
  'Time',
  'Tiny',
  'Titan',
  'Tote',
  'Tremor',
  'Trinity',
  'Turkey',
  'Turnip',
  'Twilight',
  'Valiant',
  'Water',
  'Weeping',
  'Wild',
  'Wistful',
  'XKey',
  'Yarn'
]

const second = [
  'Alamo',
  'Angel',
  'Anglo',
  'Anthropoid',
  'Aquaman',
  'Archimedes',
  'Assassin',
  'Auto',
  'Ball',
  'Bang',
  'Bank',
  'Beam',
  'Beetle',
  'Birds',
  'Bit',
  'Blossom',
  'Bobby',
  'Boom',
  'Bounce',
  'Box',
  'Broth',
  'Bumble',
  'Burst',
  'Calendar',
  'Candy',
  'Cannoli',
  'Cascade',
  'Caterpillar',
  'Chair',
  'Chef',
  'Cinnamon',
  'Cleft',
  'Club',
  'Cough',
  'Country',
  'Cyclone',
  'Cytolysis',
  'Dining',
  'Drill',
  'DriveIn',
  'Dumbo',
  'Eagle',
  'Elsa',
  'Entourage',
  'Fever',
  'Fire',
  'Flight',
  'Flock',
  'Floor',
  'Framework',
  'Galleon',
  'Gamma',
  'Genesis',
  'Ghostly',
  'Gibson',
  'Ginsu',
  'Globe',
  'Gold',
  'Gram',
  'Grasshopper',
  'Grey',
  'Hades',
  'Haul',
  'Hawk',
  'Hill',
  'Hole',
  'Hopper',
  'Hornet',
  'Horse',
  'Hurdle',
  'Improvise',
  'Intolerant',
  'Jeep',
  'Kangaroo',
  'Knave',
  'Kraken',
  'Lane',
  'Leviatan',
  'Leviticus',
  'Lithium',
  'Logic',
  'Maestro',
  'Maker',
  'Man',
  'Margarita',
  'Masquerade',
  'Master',
  'Matter',
  'Me',
  'Midnight',
  'Mint',
  'Monk',
  'Monkey',
  'Montana',
  'Mountain',
  'Mouth',
  'Mutt',
  'Nebula',
  'Net',
  'Noodle',
  'Nut',
  'Owl',
  'Packet',
  'Packrat',
  'Pandemic',
  'Payload',
  'Perseus',
  'Philosoraptor',
  'Picasso',
  'Piece',
  'Plow',
  'Pointe',
  'Poke',
  'Police',
  'Porus',
  'Potato',
  'Powerman',
  'Prince',
  'Prism',
  'Proton',
  'Pterodactyl',
  'Pup',
  'Red',
  'Ridge',
  'Rise',
  'Rock',
  'Rowe',
  'Run',
  'Salamander',
  'School',
  'Score',
  'Scotch',
  'Screamer',
  'Scribbles',
  'Set',
  'Shooter',
  'Shot',
  'Slasher',
  'Smurf',
  'Sneeze',
  'Sontaran',
  'Sparrow',
  'Spawn',
  'Spy',
  'Stand',
  'Starke',
  'Sting',
  'Stomper',
  'Surf',
  'Swap',
  'Sweeper',
  'Tap',
  'Tempora',
  'Tender',
  'Theory',
  'Thorugh',
  'Throat',
  'Toll',
  'Transgression',
  'Trap',
  'Trinity',
  'Tutu',
  'Typhon',
  'Vegetable',
  'View',
  'Vikings',
  'Wagon',
  'Walk',
  'Warrior',
  'Watch',
  'Water',
  'Wave',
  'Whispers',
  'Wire',
  'Witch',
  'Yard',
  'Zero'
]

const suffixes = [
  'HX', 'I', 'II', 'III', '2000', '4000', '9000', 'Hx9', '2.0', '3.0', 'A'
]

/**
 * Returns a nice name for a secret project or tool.
 *
 * @return {string}
 */
function getNSAName (suffix, separator) {
  let nsaname = first[Math.floor(Math.random() * first.length)] +
      separator + second[Math.floor(Math.random() * second.length)]

  if (suffix) {
    nsaname += ' ' +
            suffixes[Math.floor(Math.random() * suffixes.length)]
  }
  return nsaname
}

module.exports = {
  getNSAName: getNSAName,
  wordLists: {
    first: first,
    second: second,
    suffixes: suffixes
  }
}
